@@ -180,9 +180,9 @@ class CentralReachRequestsCore:
             "claimLabelId": "",
             "pageSize": "2000",
         }
-        response = self.session.get(load_era_list_url, json=data)
+        response = self.session.get(load_era_list_url, json=data, headers=self._get_headers(is_json=False))
         if response.status_code != 200:
-            response = self.session.get(load_era_list_url, json=data)
+            response = self.session.get(load_era_list_url, json=data, headers=self._get_headers(is_json=False))
 
         if "application/json" in response.headers.get("content-type"):
             if response.status_code == 200 and response.json().get("success", False) is True:
